@@ -1,3 +1,4 @@
+from ast import Import
 from .eos import EOSRester
 from .materials import MaterialsRester
 from .similarity import SimilarityRester
@@ -15,11 +16,9 @@ from .doi import DOIRester
 from .piezo import PiezoRester
 from .magnetism import MagnetismRester
 from .summary import SummaryRester
-from .robocrys import RobocrysRester
 from .molecules import MoleculesRester
 from .synthesis import SynthesisRester
 from .electrodes import ElectrodeRester
-from .charge_density import ChargeDensityRester
 from .electronic_structure import (
     ElectronicStructureRester,
     BandStructureRester,
@@ -30,4 +29,15 @@ from .provenance import ProvenanceRester
 from ._user_settings import UserSettingsRester
 from ._general_store import GeneralStoreRester
 from .bonds import BondsRester
-from .alloys import AlloysRester
+from .robocrys import RobocrysRester
+from .absorption import AbsorptionRester
+
+try:
+    from .alloys import AlloysRester
+except ImportError:
+    AlloysRester = None  # type: ignore
+
+try:
+    from .charge_density import ChargeDensityRester
+except ImportError:
+    ChargeDensityRester = None  # type: ignore
