@@ -1,6 +1,6 @@
 import os
 import pytest
-from mp_api.routes.materials import MaterialsRester
+from mp_api.client.routes.materials import MaterialsRester
 from emmet.core.symmetry import CrystalSystem
 
 import typing
@@ -19,11 +19,16 @@ excluded_params = [
     "num_chunks",
     "all_fields",
     "fields",
+    "exclude_elements",  # temp until server timeout increase
+    "num_elements",  # temp until server timeout increase
+    "num_sites",  # temp until server timeout increase
+    "density",  # temp until server timeout increase
 ]
 
 sub_doc_fields = []  # type: list
 
 alt_name_dict = {
+    "material_ids": "material_id",
     "formula": "material_id",
     "crystal_system": "symmetry",
     "spacegroup_number": "symmetry",
@@ -34,10 +39,10 @@ alt_name_dict = {
 }  # type: dict
 
 custom_field_tests = {
+    "material_ids": ["mp-149"],
     "formula": "Si",
     "chemsys": "Si-O",
     "elements": ["Si", "O"],
-    "exclude_elements": ["Si"],
     "task_ids": ["mp-149"],
     "crystal_system": CrystalSystem.cubic,
     "spacegroup_number": 38,
@@ -63,14 +68,14 @@ def test_client(rester):
                 if param_type == typing.Tuple[int, int]:
                     project_field = alt_name_dict.get(param, None)
                     q = {
-                        param: (-100, 100),
+                        param: (-10, 10),
                         "chunk_size": 1,
                         "num_chunks": 1,
                     }
                 elif param_type == typing.Tuple[float, float]:
                     project_field = alt_name_dict.get(param, None)
                     q = {
-                        param: (-100.12, 100.12),
+                        param: (-10.12, 10.12),
                         "chunk_size": 1,
                         "num_chunks": 1,
                     }
@@ -90,6 +95,7 @@ def test_client(rester):
                     }
 
                 doc = search_method(**q)[0].dict()
+
                 for sub_field in sub_doc_fields:
                     if sub_field in doc:
                         doc = doc[sub_field]
