@@ -1,7 +1,7 @@
 from emmet.core.symmetry import CrystalSystem
 from emmet.core.summary import HasProps
 from pymatgen.analysis.magnetism import Ordering
-from mp_api.routes.summary import SummaryRester
+from mp_api.client.routes.summary import SummaryRester
 import os
 import pytest
 
@@ -14,6 +14,12 @@ excluded_params = [
     "all_fields",
     "fields",
     "equilibrium_reaction_energy",  # temp until data update
+    "total_energy",  # temp until data update
+    "exclude_elements",  # temp until data update
+    "num_elements",  # temp until server timeout increase
+    "num_sites",  # temp until server timeout increase
+    "density",  # temp until server timeout increase
+    "total_magnetization",  # temp until server timeout increase
 ]
 
 alt_name_dict = {
@@ -42,7 +48,6 @@ custom_field_tests = {
     "formula": "SiO2",
     "chemsys": "Si-O",
     "elements": ["Si", "O"],
-    "exclude_elements": ["Si"],
     "possible_species": ["O2-"],
     "crystal_system": CrystalSystem.cubic,
     "spacegroup_number": 38,
@@ -53,10 +58,8 @@ custom_field_tests = {
     "magnetic_ordering": Ordering.FM,
 }  # type: dict
 
-@pytest.mark.skip(reason="Temporary until deployment")
-@pytest.mark.skipif(
-    os.environ.get("MP_API_KEY", None) is None, reason="No API key found."
-)
+
+@pytest.mark.skipif(os.environ.get("MP_API_KEY", None) is None, reason="No API key found.")
 def test_client():
 
     search_method = SummaryRester().search
@@ -81,14 +84,14 @@ def test_client():
             elif param_type == typing.Tuple[int, int]:
                 project_field = alt_name_dict.get(param, None)
                 q = {
-                    param: (-100, 100),
+                    param: (-10, 10),
                     "chunk_size": 1,
                     "num_chunks": 1,
                 }
             elif param_type == typing.Tuple[float, float]:
                 project_field = alt_name_dict.get(param, None)
                 q = {
-                    param: (-100.12, 100.12),
+                    param: (-10.12, 10.12),
                     "chunk_size": 1,
                     "num_chunks": 1,
                 }
